summaryrefslogtreecommitdiff
path: root/libavcodec/rtjpeg.c
diff options
context:
space:
mode:
Diffstat (limited to 'libavcodec/rtjpeg.c')
-rw-r--r--libavcodec/rtjpeg.c50
1 files changed, 23 insertions, 27 deletions
diff --git a/libavcodec/rtjpeg.c b/libavcodec/rtjpeg.c
index baa1f7857d..8e02bce2e8 100644
--- a/libavcodec/rtjpeg.c
+++ b/libavcodec/rtjpeg.c
@@ -2,26 +2,24 @@
* RTJpeg decoding functions
* Copyright (c) 2006 Reimar Doeffinger
*
- * This file is part of Libav.
+ * This file is part of FFmpeg.
*
- * Libav is free software; you can redistribute it and/or
+ * FFmpeg is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
*
- * Libav is distributed in the hope that it will be useful,
+ * FFmpeg is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
- * License along with Libav; if not, write to the Free Software
+ * License along with FFmpeg; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
-
#include "libavutil/common.h"
-
-#include "bitstream.h"
+#include "get_bits.h"
#include "rtjpeg.h"
#define PUT_COEFF(c) \
@@ -30,36 +28,34 @@
/// aligns the bitstream to the given power of two
#define ALIGN(a) \
- n = (-bitstream_tell(bc)) & (a - 1); \
- if (n) \
- bitstream_skip(bc, n);
+ n = (-get_bits_count(gb)) & (a - 1); \
+ if (n) {skip_bits(gb, n);}
/**
* @brief read one block from stream
- * @param bc contains stream data
+ * @param gb contains stream data
* @param block where data is written to
* @param scan array containing the mapping stream address -> block position
* @param quant quantization factors
* @return 0 means the block is not coded, < 0 means an error occurred.
*
* Note: BitstreamContext is used to make the code simpler, since all data is
* aligned this could be done faster in a different way, e.g. as it is done
* in MPlayer libmpcodecs/native/rtjpegn.c.
*/
-static inline int get_block(BitstreamContext *bc, int16_t *block,
- const uint8_t *scan, const uint32_t *quant)
-{
+static inline int get_block(GetBitContext *gb, int16_t *block, const uint8_t *scan,
+ const uint32_t *quant) {
int coeff, i, n;
int8_t ac;
- uint8_t dc = bitstream_read(bc, 8);
+ uint8_t dc = get_bits(gb, 8);
// block not coded
if (dc == 255)
return 0;
// number of non-zero coefficients
- coeff = bitstream_read(bc, 6);
- if (bitstream_bits_left(bc) < (coeff << 1))
+ coeff = get_bits(gb, 6);
+ if (get_bits_left(gb) < (coeff << 1))
return AVERROR_INVALIDDATA;
// normally we would only need to clear the (63 - coeff) last values,
@@ -68,7 +64,7 @@ static inline int get_block(BitstreamContext *bc, int16_t *block,
// 2 bits per coefficient
while (coeff) {
- ac = bitstream_read_signed(bc, 2);
+ ac = get_sbits(gb, 2);
if (ac == -2)
break; // continue with more bits
PUT_COEFF(ac);
@@ -76,10 +72,10 @@ static inline int get_block(BitstreamContext *bc, int16_t *block,
// 4 bits per coefficient
ALIGN(4);
- if (bitstream_bits_left(bc) < (coeff << 2))
+ if (get_bits_left(gb) < (coeff << 2))
return AVERROR_INVALIDDATA;
while (coeff) {
- ac = bitstream_read_signed(bc, 4);
+ ac = get_sbits(gb, 4);
if (ac == -8)
break; // continue with more bits
PUT_COEFF(ac);
@@ -87,10 +83,10 @@ static inline int get_block(BitstreamContext *bc, int16_t *block,
// 8 bits per coefficient
ALIGN(8);
- if (bitstream_bits_left(bc) < (coeff << 3))
+ if (get_bits_left(gb) < (coeff << 3))
return AVERROR_INVALIDDATA;
while (coeff) {
- ac = bitstream_read_signed(bc, 8);
+ ac = get_sbits(gb, 8);
PUT_COEFF(ac);
}
@@ -109,19 +105,19 @@ static inline int get_block(BitstreamContext *bc, int16_t *block,
*/
int ff_rtjpeg_decode_frame_yuv420(RTJpegContext *c, AVFrame *f,
const uint8_t *buf, int buf_size) {
- BitstreamContext bc;
+ GetBitContext gb;
int w = c->w / 16, h = c->h / 16;
int x, y, ret;
uint8_t *y1 = f->data[0], *y2 = f->data[0] + 8 * f->linesize[0];
uint8_t *u = f->data[1], *v = f->data[2];
- if ((ret = bitstream_init8(&bc, buf, buf_size)) < 0)
+ if ((ret = init_get_bits8(&gb, buf, buf_size)) < 0)
return ret;
for (y = 0; y < h; y++) {
for (x = 0; x < w; x++) {
#define BLOCK(quant, dst, stride) do { \
- int res = get_block(&bc, block, c->scan, quant); \
+ int res = get_block(&gb, block, c->scan, quant); \
if (res < 0) \
return res; \
if (res > 0) \
@@ -146,7 +142,7 @@ int ff_rtjpeg_decode_frame_yuv420(RTJpegContext *c, AVFrame *f,
u += 8 * (f->linesize[1] - w);
v += 8 * (f->linesize[2] - w);
}
- return bitstream_tell(&bc) / 8;
+ return get_bits_count(&gb) / 8;
}
/**
@@ -30,36 +28,34 @@
* @return 0 means the block is not coded, < 0 means an error occurred.
*
- * Note: BitstreamContext is used to make the code simpler, since all data is
+ * Note: GetBitContext is used to make the code simpler, since all data is
* aligned this could be done faster in a different way, e.g. as it is done
* in MPlayer libmpcodecs/native/rtjpegn.c.